@@ -3,6 +3,7 @@
 
 """The GUI for playing chess using KingSnake!"""
 
+import pickle
 import sys
 import time
 
@@ -16,10 +17,9 @@ class ChessGame(object):
     """A chess game manager"""
 
     def __init__(self):
-        player1, player2 = Player(), Player()
-        self.white, self.black = player1, player2
+        self.white, self.black = Player(), Player()
         self.chessboard = Chessboard()
-        self.chessboard.add_players(player1, player2)
+        self.chessboard.add_players(self.white, self.black)
         self.greet()
 
     def greet(self):
@@ -77,21 +77,31 @@ class ChessGame(object):
 
         def save_game():
             """Save game to file."""
-            raise NotImplementedError
+            file_name = raw_input("What file would you like to save to?: ")
+            try:
+                with open(file_name, "w") as saved_game:
+                    pickle.dump(self.chessboard, saved_game)
+            except IOError:
+                self.get_move("The file you have chosen is invalid. "
+                              "Please enter a valid filename.")
+            self.get_move("Game saved to {}.".format(file_name))
 
         def load_game():
             """Load game from file."""
-            raise NotImplementedError
+            file_name = raw_input("What file would you like to load from?: ")
+            try:
+                with open(file_name) as saved_game:
+                    self.chessboard = pickle.load(saved_game)
+                    self.white = self.chessboard.players["white"]
+                    self.black = self.chessboard.players["black"]
+            except IOError:
+                self.get_move("The file you have chosen is invalid. "
+                              "Please enter a valid filename.")
 
         def undo_turn():
             """Undo turn."""
-            try:
-                self.chessboard = self.chessboard.previous_move
-                self.white = self.chessboard.players["white"]
-                self.black = self.chessboard.players["black"]
-                self.get_move("Move restored.")
-            except AttributeError:
-                self.get_move("You are already at the first move.")
+            self.chessboard.rollback()
+            self.get_move("Move restored.")
 
         def return_to_game():
             """Resume play."""
