@@ -17,37 +17,16 @@ class Player(object):
 
     def __str__(self):
         if self.chessboard:
-            if self == self.chessboard.players["white"]:
-                color = "White"
-            else:
-                color = "Black"
             return_string = ("{color} Player on "
                              "{chessboard}\n"
                              "Figures: "
-                             "{figures}".format(color=color,
+                             "{figures}".format(color=self.color,
                                                 chessboard=self.chessboard,
                                                 figures=self.figures))
         else:
             return_string = self.__repr__()
         return return_string
 
-    @staticmethod
-    def rollback(moved_piece, captured_piece=None):
-        """
-        Reverse a turn.
-
-        @param moved_piece - Tuple of piece moved during the move with its old
-                             position
-        @param captured_piece - Tuple for captured piece, formated as above
-        """
-        rollback_pieces = [moved_piece]
-        if captured_piece:
-            rollback_pieces.append(captured_piece)
-
-        for piece in rollback_pieces:
-            piece["old_position"].receive_figure(piece["figure"])
-            piece["figure"].position = piece["old_position"]
-
     def __init__(self):
         self.chessboard = None
         self.figures = None
@@ -57,7 +36,7 @@ class Player(object):
     @property
     def opponent(self):
         """Return other player in chess game"""
-        if self == self.chessboard.players["white"]:
+        if self.color == "white":
             return self.chessboard.players["black"]
         else:
             return self.chessboard.players["white"]
@@ -65,6 +44,10 @@ class Player(object):
     def set_up_board(self, chessboard):
         """Set up pieces on given chessboard and find other player."""
         self.chessboard = chessboard
+        if self == self.chessboard.players["white"]:
+            self.color = "white"
+        else:
+            self.color = "black"
         self.figures = list(Pawn(self) for pawns in range(8))
         for doubled_piece in (Rook, Knight, Bishop) * 2:
             self.figures.append(doubled_piece(self))
@@ -72,7 +55,7 @@ class Player(object):
         self.king = King(self)
         self.figures.append(self.king)
 
-    def move(self, start_field, goal_field):
+    def move(self, start, goal):
         """
         Move a piece to a new field.
 
@@ -86,12 +69,11 @@ class Player(object):
         @param start_field - String used to look up field object (e.g. "E2")
         @param goal_field - Like start_field
         """
-        self.chessboard.store_state()
         if self != self.chessboard.current_player:
             raise TurnError("Move attempted out of turn.")
 
-        start_field = self.chessboard.fields[start_field]
-        goal_field = self.chessboard.fields[goal_field]
+        start_field = self.chessboard.fields[start]
+        goal_field = self.chessboard.fields[goal]
 
         figure = start_field.figure
         if not figure in self.figures:
@@ -105,14 +87,13 @@ class Player(object):
             captured_piece = figure.capture(goal_field)
         except FieldMustBeCastledError:
             captured_piece = figure.castle(goal_field)
-        moved_piece = {"figure": figure, "old_position": start_field}
 
         if self.king.in_check:
-            self.rollback(moved_piece, captured_piece)
+            self.chessboard.rollback()
             raise IllegalMoveError("Move would put player's king in check.")
 
         figure.already_moved = True
         figure.last_moved = self.chessboard.current_move
         if captured_piece:
-            captured_piece["figure"].last_moved = self.chessboard.current_move
-        self.chessboard.end_turn()
+            captured_piece.last_moved = self.chessboard.current_move
+        self.chessboard.end_turn(start, goal)
